aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/cpp/blaze_util.h
diff options
context:
space:
mode:
authorGravatar lpino <lpino@google.com>2017-08-10 16:25:54 +0200
committerGravatar Marcel Hlopko <hlopko@google.com>2017-08-11 12:55:58 +0200
commit4ed3db6517c7e13f46924fb832c0d65b70c95cde (patch)
treeb8c37fff1de2fdaf7f89d958a891cfc05077449c /src/main/cpp/blaze_util.h
parentdb55b5a9f6d56535a909bd777b7f803a99d9dbd9 (diff)
Polish blaze_util.cc
PiperOrigin-RevId: 164850909
Diffstat (limited to 'src/main/cpp/blaze_util.h')
-rw-r--r--src/main/cpp/blaze_util.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/main/cpp/blaze_util.h b/src/main/cpp/blaze_util.h
index 7c85d82dbf..0df70e67df 100644
--- a/src/main/cpp/blaze_util.h
+++ b/src/main/cpp/blaze_util.h
@@ -57,12 +57,21 @@ bool GetNullaryOption(const char *arg, const char *key);
const char* SearchUnaryOption(const std::vector<std::string>& args,
const char* key);
// Searches for 'key' in 'args' using GetNullaryOption. Arguments found after
// '--' are omitted from the search.
// Returns true iff key is a flag in args.
bool SearchNullaryOption(const std::vector<std::string>& args,
const char* key);
+// Searches for 'key' in 'args' using GetNullaryOption.
+// Unlike SearchNullaryOption, arguments found after '--' are included in the
+// search.
+// Returns true iff key is a flag in args.
+bool SearchNullaryOptionEverywhere(const std::vector<std::string>& args,
+ const char* key);
+
+
// Enable messages mostly of interest to developers.
bool VerboseLogging();
@@ -57,12 +57,21 @@ bool GetNullaryOption(const char *arg, const char *key);
const char* SearchUnaryOption(const std::vector<std::string>& args,
const char* key);
-// Searches for 'key' in 'args' using GetNullaryOption. Arguments found after
-// '--' are omitted from the search.
+// Searches for 'key' in 'args' using GetNullaryOption.
+// Unlike SearchNullaryOptionEverywhere, arguments found after '--' are omitted
+// from the search.
// Returns true iff key is a flag in args.
bool SearchNullaryOption(const std::vector<std::string>& args,